@@ -38,7 +38,9 @@ Test::Mojo::Role::Session - Testing session in Mojolicious applications
     ->session_has('/s1')
     ->session_is('/s1' => 'session data')
     ->session_hasnt('/s2')
-    ->session_is('/s3' => [1, 3]);
+    ->session_is('/s3' => [1, 3])
+    ->session_like('/s1' => qr/data/, 's1 contains "data"')
+    ->session_unlike('/s1' => qr/foo/, 's1 does not contain "foo"');
 
   done_testing();
 
